@@ -1,5 +1,5 @@
 # This file is part of MyPaint.
-# Copyright (C) 2012 by Andrew Chadwick <andrewc-git@piffle.org>
+# Copyright (C) 2012-2019 by the MyPaint Development Team.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -9,52 +9,47 @@
 
 """Viewer and editor widgets for palettes."""
 
-# Editor ideas:
+# Editor ideas
 #   - "Insert lighter/darker copy of row".
 #   - repack palette (remove duplicates and blanks)
 #   - sort palette by approx. hue+chroma binning, then luma variations
 
 
 ## Imports
+from __future__ import division, print_function
 
 import math
-from copy import deepcopy
 import os
 import re
 import logging
-logger = logging.getLogger(__name__)
+from io import open
 
-import gi
 from gi.repository import Gdk
 from gi.repository import Gtk
 from gi.repository import GLib
 import cairo
 from lib.gettext import C_
 
-from lib.observable import event
-from util import clamp
+from .util import clamp
 from lib.palette import Palette
 from lib.color import RGBColor
 from lib.color import HCYColor
 from lib.color import HSVColor
 import gui.uicolor
+from .adjbases import ColorAdjuster
+from .adjbases import ColorAdjusterWidget
+from .adjbases import ColorManager
+from .adjbases import DATAPATH_PALETTES_SUBDIR
+from .combined import CombinedAdjusterPage
+
+from lib.pycompat import unicode
 
 
-## Imports still requiring gtk2compat
-
-if __name__ == '__main__':
-    import gui.gtk2compat
-from uimisc import borderless_button
-from adjbases import ColorAdjuster
-from adjbases import ColorAdjusterWidget
-from adjbases import ColorManager
-from adjbases import DATAPATH_PALETTES_SUBDIR
-from combined import CombinedAdjusterPage
+logger = logging.getLogger(__name__)
 
 
 ## Class defs
 
-
 class PalettePage (CombinedAdjusterPage):
     """User-editable palette, as a `CombinedAdjuster` element."""
 
@@ -66,22 +61,22 @@ class PalettePage (CombinedAdjusterPage):
         self._edit_dialog = None
 
     @classmethod
-    def get_properties_description(class_):
+    def get_properties_description(cls):
         return C_(
             "palette panel: properties button tooltip",
             "Palette properties",
         )
 
     @classmethod
-    def get_page_icon_name(self):
+    def get_page_icon_name(cls):
         return "mypaint-tool-color-palette"
 
     @classmethod
-    def get_page_title(self):
+    def get_page_title(cls):
         return C_("palette panel tab tooltip title", "Palette")
 
     @classmethod
-    def get_page_description(self):
+    def get_page_description(cls):
         return C_(
             "palette panel tab tooltip description",
             "Set the color from a loadable, editable palette.",
@@ -114,16 +109,15 @@ class PaletteEditorDialog (Gtk.Dialog):
     )
 
     def __init__(self, parent, target_color_manager):
-        flags = Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT
         Gtk.Dialog.__init__(
             self,
-            C_("palette editor dialog: title", "Palette Editor"),
-            parent,
-            flags,
-            buttons=(
-                Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT,
-                Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT,
-            ))
+            title=C_("palette editor dialog: title", "Palette Editor"),
+            transient_for=parent,
+            modal=True,
+            destroy_with_parent=True,
+        )
+        self.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT)
+        self.add_button(Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT)
         self.set_position(Gtk.WindowPosition.MOUSE)
 
         assert isinstance(target_color_manager, ColorManager)
@@ -150,11 +144,11 @@ class PaletteEditorDialog (Gtk.Dialog):
         add_btn = self._add_button = Gtk.Button(stock=Gtk.STOCK_ADD)
         remove_btn = self._remove_button = Gtk.Button(stock=Gtk.STOCK_REMOVE)
         clear_btn = self._clear_button = Gtk.Button(stock=Gtk.STOCK_CLEAR)
-        action_bbox.pack_start(load_btn)
-        action_bbox.pack_start(save_btn)
-        action_bbox.pack_start(add_btn)
-        action_bbox.pack_start(remove_btn)
-        action_bbox.pack_start(clear_btn)
+        action_bbox.pack_start(load_btn, True, True, 0)
+        action_bbox.pack_start(save_btn, True, True, 0)
+        action_bbox.pack_start(add_btn, True, True, 0)
+        action_bbox.pack_start(remove_btn, True, True, 0)
+        action_bbox.pack_start(clear_btn, True, True, 0)
         action_bbox.set_layout(Gtk.ButtonBoxStyle.START)
         load_btn.connect("clicked", self._load_btn_clicked)
         save_btn.connect("clicked", self._save_btn_clicked)
@@ -191,7 +185,7 @@ class PaletteEditorDialog (Gtk.Dialog):
 
         # Palette name and number of entries
         palette_details_hbox = Gtk.HBox()
-        palette_name_label = Gtk.Label(C_(
+        palette_name_label = Gtk.Label(label=C_(
             "palette editor dialog: palette name/title entry: label",
             "Title:",
         ))
@@ -204,10 +198,10 @@ class PaletteEditorDialog (Gtk.Dialog):
         self._palette_name_entry = palette_name_entry
         self._columns_adj = Gtk.Adjustment(
             value=0, lower=0, upper=99,
-            step_incr=1, page_incr=1, page_size=0
+            step_increment=1, page_increment=1, page_size=0
         )
         self._columns_adj.connect("value-changed", self._columns_changed_cb)
-        columns_label = Gtk.Label(C_(
+        columns_label = Gtk.Label(label=C_(
             "palette editor dialog: number-of-columns spinbutton: title",
             "Columns:"
         ))
@@ -228,7 +222,7 @@ class PaletteEditorDialog (Gtk.Dialog):
         palette_details_hbox.pack_start(columns_spinbutton, False, False, 0)
 
         color_name_hbox = Gtk.HBox()
-        color_name_label = Gtk.Label(C_(
+        color_name_label = Gtk.Label(label=C_(
             "palette editor dialog: color name entry: label",
             "Color name:",
         ))
@@ -246,18 +240,18 @@ class PaletteEditorDialog (Gtk.Dialog):
 
         palette_vbox = Gtk.VBox()
         palette_vbox.set_spacing(12)
-        palette_vbox.pack_start(palette_details_hbox, False, False)
-        palette_vbox.pack_start(view, True, True)
-        palette_vbox.pack_start(color_name_hbox, False, False)
+        palette_vbox.pack_start(palette_details_hbox, False, False, 0)
+        palette_vbox.pack_start(view, True, True, 0)
+        palette_vbox.pack_start(color_name_hbox, False, False, 0)
 
         # Dialog contents
         # Main edit area to the left, buttons to the right
         hbox = Gtk.HBox()
         hbox.set_spacing(12)
-        hbox.pack_start(palette_vbox, True, True)
-        hbox.pack_start(action_bbox, False, False)
+        hbox.pack_start(palette_vbox, True, True, 0)
+        hbox.pack_start(action_bbox, False, False, 0)
         hbox.set_border_width(12)
-        self.vbox.pack_start(hbox, True, True)
+        self.vbox.pack_start(hbox, True, True, 0)
 
         # Dialog vbox contents must be shown separately
         for w in self.vbox:
@@ -419,7 +413,7 @@ class PaletteView (ColorAdjuster, Gtk.ScrolledWindow):
 
     """
 
-    ## Sizing contraint constants
+    ## Sizing constraint constants
     _MIN_HEIGHT = 32
     _MIN_WIDTH = 150
     _MAX_NATURAL_HEIGHT = 300
@@ -429,7 +423,7 @@ class PaletteView (ColorAdjuster, Gtk.ScrolledWindow):
         Gtk.ScrolledWindow.__init__(self)
         self.grid = _PaletteGridLayout()
         self.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
-        self.add_with_viewport(self.grid)
+        self.add(self.grid)
 
     def set_color_manager(self, mgr):
         self.grid.set_color_manager(mgr)
@@ -492,22 +486,22 @@ class _PalettePreview (Gtk.DrawingArea):
             s = w / ncolumns
             s = clamp(s, s_min, s_max)
             s = int(s)
-            if s*ncolumns > w:
+            if (s * ncolumns) > w:
                 ncolumns = 0
         if ncolumns == 0:
-            s = math.sqrt(float(w*h) / ncolors)
+            s = math.sqrt((w * h) / ncolors)
             s = clamp(s, s_min, s_max)
             s = int(s)
-            ncolumns = max(1, int(w / s))
+            ncolumns = max(1, int(w // s))
         nrows = int(ncolors // ncolumns)
         if ncolors % ncolumns != 0:
             nrows += 1
         nrows = max(1, nrows)
         dx, dy = 0, 0
-        if nrows*s < h:
-            dy = int(h - nrows*s) / 2
-        if ncolumns*s < w:
-            dx = int(w - ncolumns*s) / 2
+        if (nrows * s) < h:
+            dy = int(h - (nrows * s)) // 2
+        if (ncolumns * s) < w:
+            dx = int(w - (ncolumns * s)) // 2
         bg_color = _widget_get_bg_color(self)
         _palette_render(self._palette, cr, rows=nrows, columns=ncolumns,
                         swatch_size=s, bg_color=bg_color,
@@ -591,23 +585,23 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         ncolors, nrows, ncolumns = self._get_palette_dimensions()
         if nrows and ncolumns:
             # Fitted to the major dimension
-            size = int(min(width/ncolumns, height/nrows))
+            size = int(min(width / ncolumns, height / nrows))
             size = self._constrain_swatch_size(size)
         else:
             # Free-flowing
             if ncolors > 0:
-                size = int(math.sqrt(float(width*height) / ncolors))
+                size = int(math.sqrt((width * height) / ncolors))
                 size = self._constrain_swatch_size(size)
-                ncolumns = max(1, min(ncolors, width / size))
-                nrows = max(1, int(ncolors / ncolumns))
+                ncolumns = max(1, min(ncolors, width // size))
+                nrows = max(1, int(ncolors // ncolumns))
                 if int(ncolors % ncolumns) > 0:
                     nrows += 1
                 if nrows * size > height or ncolumns * size > width:
-                    size = max(1, min(int(height / nrows),
-                                      int(width / ncolumns)))
+                    size = max(1, min(int(height // nrows),
+                                      int(width // ncolumns)))
                     size = self._constrain_swatch_size(size)
-                    ncolumns = max(1, min(ncolors, width / size))
-                    nrows = max(1, int(ncolors / ncolumns))
+                    ncolumns = max(1, min(ncolors, width // size))
+                    nrows = max(1, int(ncolors // ncolumns))
                     if int(ncolors % ncolumns) > 0:
                         nrows += 1
             else:
@@ -735,13 +729,12 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         mx, my = self.get_position_for_index(i)
         mx = event.x_root - x + mx + self._swatch_size
         my = event.y_root - y + my + self._swatch_size
-        pos_func = lambda *a: (mx, my, True)
         menu = self._get_context_menu(i)
         menu.show_all()
         menu.popup(
             parent_menu_shell = None,
             parent_menu_item = None,
-            func = pos_func,
+            func = lambda *a: (mx, my, True),
             data = None,
             button = event.button,
             activate_time = event.time,
@@ -787,40 +780,44 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         palette = self.get_color_manager().palette
         empty_range = self._get_empty_range(i)
         item_defs = [
-            #TRANSLATORS: inserting gaps (empty color swatches)
             (
+                # TRANSLATORS: inserting gaps (empty color swatches)
                 C_("palette view: context menu", "Add Empty Slot"),
                 self._insert_empty_slot_cb,
                 True,
                 [i],
             ),
             (
+                # TRANSLATORS: inserting gaps (empty color swatches)
                 C_("palette view: context menu", "Insert Row"),
                 self._insert_empty_row_cb,
                 True,
                 [i],
             ),
             (
+                # TRANSLATORS: inserting gaps (empty color swatches)
                 C_("palette view: context menu", "Insert Column"),
                 self._insert_empty_column_cb,
                 bool(palette.get_columns()),
                 [i],
             ),
             None,
-            #TRANSLATORS: Color interpolations
             (
+                # TRANSLATORS: Color interpolations
                 C_("palette view: context menu", "Fill Gap (RGB)"),
                 self._interpolate_empty_range_cb,
                 bool(empty_range),
                 [RGBColor, empty_range],
             ),
             (
+                # TRANSLATORS: Color interpolations
                 C_("palette view: context menu", "Fill Gap (HCY)"),
                 self._interpolate_empty_range_cb,
                 bool(empty_range),
                 [HCYColor, empty_range],
             ),
             (
+                # TRANSLATORS: Color interpolations
                 C_("palette view: context menu", "Fill Gap (HSV)"),
                 self._interpolate_empty_range_cb,
                 bool(empty_range),
@@ -868,7 +865,7 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         row_di = target_i % self._columns
         columns_new = palette.get_columns() + 1
         r = 0
-        while r*columns_new < len(palette):
+        while r * columns_new < len(palette):
             i = r * columns_new + row_di
             if i >= len(palette):
                 break
@@ -877,14 +874,14 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         palette.set_columns(columns_new)
 
     def _interpolate_empty_range_cb(self, menuitem, color_class, range):
-        i0, iN = range
+        i0, ix = range
         palette = self.get_color_manager().palette
         c0 = color_class(color=palette[i0])
-        cN = color_class(color=palette[iN])
-        nsteps = iN - i0 + 1
+        cx = color_class(color=palette[ix])
+        nsteps = ix - i0 + 1
         if nsteps < 3:
             return
-        interpolated = list(c0.interpolate(cN, nsteps))
+        interpolated = list(c0.interpolate(cx, nsteps))
         assert len(interpolated) == nsteps
         interpolated.pop(0)
         interpolated.pop(-1)
@@ -917,7 +914,7 @@ class _PaletteGridLayout (ColorAdjusterWidget):
             ncolumns = int(ncolumns)
             if ncolors > 0:
                 ncolumns = min(ncolumns, ncolors)
-                nrows = max(1, int(ncolors / ncolumns))
+                nrows = max(1, int(ncolors // ncolumns))
                 if int(ncolors % ncolumns) > 0:
                     nrows += 1
             else:
@@ -956,14 +953,14 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         ncolors, nrows, ncolumns = self._get_palette_dimensions()
         if nrows and ncolumns:
             # Horizontal fit
-            swatch_size = self._constrain_swatch_size(int(width / ncolumns))
+            swatch_size = self._constrain_swatch_size(int(width // ncolumns))
             min_h = self._SWATCH_SIZE_MIN * nrows
             nat_h = swatch_size * nrows
         else:
             # Free-flowing, across and then down
             # Since s = sqrt((w*h)/n),
-            min_h = int((((self._SWATCH_SIZE_MIN)**2)*ncolors) / width)
-            nat_h = int((((self._SWATCH_SIZE_NOMINAL)**2)*ncolors) / width)
+            min_h = int(((self._SWATCH_SIZE_MIN ** 2) * ncolors) // width)
+            nat_h = int(((self._SWATCH_SIZE_NOMINAL ** 2) * ncolors) // width)
         return min_h, max(min_h, nat_h)
 
     def do_get_preferred_height(self):
@@ -986,7 +983,7 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         ncolors, nrows, ncolumns = self._get_palette_dimensions()
         if nrows and ncolumns:
             # Vertical fit
-            swatch_size = self._constrain_swatch_size(int(height / nrows))
+            swatch_size = self._constrain_swatch_size(int(height // nrows))
             min_w = self._SWATCH_SIZE_MIN * ncolumns
             nat_w = swatch_size * ncolumns
         else:
@@ -1029,7 +1026,7 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         # Background (shadow)
         cr.set_source_rgb(*bg_rgb)
         cr.set_line_width(bg_width)
-        cr.rectangle(x, y, w-1, h-1)
+        cr.rectangle(x, y, w - 1, h - 1)
 
         cr.set_dash(bg_dash)
         cr.stroke_preserve()
@@ -1078,10 +1075,10 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         dx, dy = self.get_painting_offset()
         s_w = s_h = self._swatch_size
         c = i % self._columns
-        r = int(i / self._columns)
-        x = 0.5 + c*s_w
-        y = 0.5 + r*s_h
-        return x+dx, y+dy
+        r = int(i // self._columns)
+        x = 0.5 + (c * s_w)
+        y = 0.5 + (r * s_h)
+        return (x + dx, y + dy)
 
     def get_painting_offset(self):
         if None in (self._rows, self._columns):
@@ -1093,10 +1090,10 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         wd, ht = alloc.width, alloc.height
         dx, dy = 0, 0
         if l_wd < wd:
-            dx = (wd - l_wd)/2.0
+            dx = (wd - l_wd) / 2.0
         if l_ht < ht:
-            dy = (ht - l_ht)/2.0
-        return 1+int(dx), 1+int(dy)
+            dy = (ht - l_ht) / 2.0
+        return 1 + int(dx), 1 + int(dy)
 
     def get_color_at_position(self, x, y):
         i = self.get_index_at_pos(x, y)
@@ -1138,8 +1135,8 @@ class _PaletteGridLayout (ColorAdjusterWidget):
         dx, dy = self.get_painting_offset()
         s_wd = s_ht = self._swatch_size
         # Calculate a raw row and column
-        r = int((y-dy) // s_ht)
-        c = int((x-dx) // s_wd)
+        r = int((y - dy) // s_ht)
+        c = int((x - dx) // s_wd)
         # Check position is within range, or constrain for nearest
         if r < 0:
             if not nearest:
@@ -1158,7 +1155,7 @@ class _PaletteGridLayout (ColorAdjusterWidget):
                 return None
             c = self._columns - 1
         # Index range check too: the last row may not be fully populated
-        i = r*self._columns + c
+        i = (r * self._columns) + c
         if i >= len(mgr.palette):
             if not nearest:
                 return None
@@ -1261,11 +1258,11 @@ def palette_load_via_dialog(title, parent=None, preview=None,
     """
     dialog = Gtk.FileChooserDialog(
         title=title,
-        parent=parent,
+        transient_for=parent,
         action=Gtk.FileChooserAction.OPEN,
-        buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT,
-                 Gtk.STOCK_OPEN, Gtk.ResponseType.ACCEPT),
     )
+    dialog.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT)
+    dialog.add_button(Gtk.STOCK_OPEN, Gtk.ResponseType.ACCEPT)
     if preview is not None:
         dialog.set_preview_widget(preview)
         dialog.connect("update-preview",
@@ -1313,11 +1310,11 @@ def palette_save_via_dialog(palette, title, parent=None, preview=None):
     """
     dialog = Gtk.FileChooserDialog(
         title=title,
-        parent=parent,
+        transient_for=parent,
         action=Gtk.FileChooserAction.SAVE,
-        buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT,
-                 Gtk.STOCK_SAVE, Gtk.ResponseType.ACCEPT),
     )
+    dialog.add_button(Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT)
+    dialog.add_button(Gtk.STOCK_SAVE, Gtk.ResponseType.ACCEPT)
     if preview is not None:
         dialog.set_preview_widget(preview)
         dialog.connect("update-preview",
@@ -1348,10 +1345,9 @@ def palette_save_via_dialog(palette, title, parent=None, preview=None):
         # FIXME: this can overwrite files without prompting the user, if
         # the name hacking above changed the filename.  Should do the name
         # tweak within the dialog somehow and get that to confirm.
-        fp = open(filename, 'w')
-        palette.save(fp)
-        fp.flush()
-        fp.close()
+        with open(filename, 'w', encoding="utf-8", errors="replace") as fp:
+            palette.save(fp)
+            fp.flush()
         result = True
     dialog.destroy()
     return result
@@ -1364,7 +1360,7 @@ def _palette_loadsave_dialog_update_preview_cb(dialog, preview):
     if filename is not None and os.path.isfile(filename):
         try:
             palette = Palette(filename=filename)
-        except Exception, ex:
+        except Exception as ex:
             logger.warning("Couldn't update preview widget: %s", str(ex))
             return
     if palette is not None and len(palette) > 0:
@@ -1393,7 +1389,7 @@ def _palette_render(palette, cr, rows, columns, swatch_size,
                  instead of left to right. Currently ignored.
     """
 
-    HIGHLIGHT_DLUMA = 0.05
+    highlight_dluma = 0.05
 
     if len(palette) == 0:
         return
@@ -1406,15 +1402,15 @@ def _palette_render(palette, cr, rows, columns, swatch_size,
     # Sizes and colors
     swatch_w = swatch_h = swatch_size
     light_col = HCYColor(color=bg_color)
-    light_col.y += HIGHLIGHT_DLUMA
+    light_col.y += highlight_dluma
     dark_col = HCYColor(color=bg_color)
-    dark_col.y -= HIGHLIGHT_DLUMA
+    dark_col.y -= highlight_dluma
     if light_col.y >= 1:
         light_col.y = 1.0
-        dark_col.y = 1.0 - (2*HIGHLIGHT_DLUMA)
+        dark_col.y = 1.0 - (2 * highlight_dluma)
     if dark_col.y <= 0:
         dark_col.y = 0.0
-        light_col.y = 0.0 + (2*HIGHLIGHT_DLUMA)
+        light_col.y = 0.0 + (2 * highlight_dluma)
 
     # Upper left outline (bottom right is covered below by the
     # individual chips' shadows)
@@ -1424,10 +1420,10 @@ def _palette_render(palette, cr, rows, columns, swatch_size,
     cr.set_line_join(cairo.LINE_JOIN_ROUND)
     cr.set_line_cap(cairo.LINE_CAP_ROUND)
     cr.set_source_rgb(*ul_col.get_rgb())
-    cr.move_to(0.5, rows*swatch_h - 1)
+    cr.move_to(0.5, (rows * swatch_h) - 1)
     cr.line_to(0.5, 0.5)
     row1cells = min(columns, len(palette))  # needed?
-    cr.line_to(row1cells*swatch_w - 1, 0.5)
+    cr.line_to((row1cells * swatch_w) - 1, 0.5)
     cr.set_line_width(2)
     cr.stroke()
 
@@ -1436,8 +1432,8 @@ def _palette_render(palette, cr, rows, columns, swatch_size,
     cr.set_line_width(1.0)
     cr.set_line_cap(cairo.LINE_CAP_SQUARE)
     for col in palette.iter_colors():
-        s_x = c*swatch_w
-        s_y = r*swatch_h
+        s_x = c * swatch_w
+        s_y = r * swatch_h
         s_w = swatch_w
         s_h = swatch_h
 
@@ -1470,18 +1466,18 @@ def _palette_render(palette, cr, rows, columns, swatch_size,
         cr.rectangle(s_x, s_y, s_w, s_h)
         cr.fill()
         cr.set_source_rgb(*fill_bg_rgb)
-        cr.rectangle(s_x, s_y, s_w-1, s_h-1)
+        cr.rectangle(s_x, s_y, s_w - 1, s_h - 1)
         cr.fill()
         if fill_fg_rgb is not None:
-            s_w2 = int((s_w-1) / 2)
-            s_h2 = int((s_h-1) / 2)
+            s_w2 = int((s_w - 1) // 2)
+            s_h2 = int((s_h - 1) // 2)
             cr.set_source_rgb(*fill_fg_rgb)
             cr.rectangle(s_x, s_y, s_w2, s_h2)
             cr.fill()
-            cr.rectangle(s_x+s_w2, s_y+s_h2, s_w2, s_h2)
+            cr.rectangle(s_x + s_w2, s_y + s_h2, s_w2, s_h2)
             cr.fill()
         cr.set_source_rgb(*hi_rgb)
-        cr.rectangle(s_x+0.5, s_y+0.5, s_w-2, s_h-2)
+        cr.rectangle(s_x + 0.5, s_y + 0.5, s_w - 2, s_h - 2)
         cr.stroke()
 
         c += 1
